@@ -17,13 +17,15 @@ from databricks_cli.sdk import DbfsService, JobsService
 
 
 class ProphecyBuildTool:
-    def __init__(self, path_root: str):
+    def __init__(self, path_root: str, mvn_params: str):
         print(
-            "[bold purple]Prophecy-build-tool[/bold purple] [bold black]v1.0.1[/bold black]\n"
+            "[bold purple]Prophecy-build-tool[/bold purple] [bold black]v1.0.3[/bold black]\n"
         )
+        if not path_root:
+            self._error("Path of project not passed as argument using --path.")
 
         self.operating_system = sys.platform
-
+        self.mvn_params = mvn_params
         self.path_root = path_root
         self.path_project = os.path.join(self.path_root, "pbt_project.yml")
 
@@ -39,29 +41,44 @@ class ProphecyBuildTool:
         self.jobs_service = JobsService(self.api_client)
         self.python_cmd, self.pip_cmd = self.get_python_commands(path_root)
         self.pipelines_build_path = {}
+        self.project_release = os.getenv(
+            "PROJECT_RELEASE_VERSION_PLACEHOLDER",
+            "__PROJECT_RELEASE_VERSION_PLACEHOLDER__",
+        )
+        self.project_id = os.getenv(
+            "PROJECT_ID_PLACEHOLDER", "__PROJECT_ID_PLACEHOLDER__"
+        )
 
     def get_python_commands(self, cwd):
-        if Process.process_sequential(
+        if (
+            Process.process_sequential(
                 [
                     Process(
                         ["python3", "--version"],
                         cwd,
                         subprocess.DEVNULL,
                         subprocess.DEVNULL,
-                        (self.operating_system == "win32")
+                        (self.operating_system == "win32"),
                     )
-                ]) == 0:
+                ]
+            )
+            == 0
+        ):
             return "python3", "pip3"
-        elif Process.process_sequential(
+        elif (
+            Process.process_sequential(
                 [
                     Process(
                         ["python", "--version"],
                         cwd,
                         subprocess.DEVNULL,
                         subprocess.DEVNULL,
-                        (self.operating_system == "win32")
+                        (self.operating_system == "win32"),
                     )
-                ]) == 0:
+                ]
+            )
+            == 0
+        ):
             return "python", "pip"
         else:
             print("ERROR: python not found")
@@ -150,6 +167,15 @@ class ProphecyBuildTool:
             )
             path_job_definition = os.path.join(path_job_absolute, "databricks-job.json")
 
+            with open(path_job_definition, "r") as _in:
+                data = _in.read()
+                data = data.replace(
+                    "__PROJECT_RELEASE_VERSION_PLACEHOLDER__", self.project_release
+                )
+                data = data.replace("__PROJECT_ID_PLACEHOLDER__", self.project_id)
+            with open(path_job_definition, "w") as _out:
+                _out.write(data)
+
             with open(path_job_definition, "r") as _in:
                 job_definition = json.load(_in)
 
@@ -199,7 +225,10 @@ class ProphecyBuildTool:
                 # Process next job
                 continue
 
-            job_request = job_definition["request"]["CreateNewJobRequest"]
+            job_request = job_definition["request"]
+            if "CreateNewJobRequest" in job_request.keys():
+                job_request = job_definition["request"]["CreateNewJobRequest"]
+
             job_request["version"] = "2.1"
 
             limit = 25
@@ -218,8 +247,8 @@ class ProphecyBuildTool:
                     found_jobs = response["jobs"] if "jobs" in response else []
                     for potential_found_job in found_jobs:
                         if (
-                                potential_found_job["settings"]["name"]
-                                == job_request["name"]
+                            potential_found_job["settings"]["name"]
+                            == job_request["name"]
                         ):
                             found_job = potential_found_job
                             break
@@ -227,7 +256,10 @@ class ProphecyBuildTool:
                     if len(found_jobs) <= 0:
                         break
 
-                job_request = job_definition["request"]["CreateNewJobRequest"]
+                job_request = job_definition["request"]
+                if "CreateNewJobRequest" in job_request.keys():
+                    job_request = job_definition["request"]["CreateNewJobRequest"]
+
                 if found_job is None:
                     print("    Creating a new job: %s" % (job_request["name"]))
                     self.jobs_service.create_job(**job_request)
@@ -263,7 +295,7 @@ class ProphecyBuildTool:
             unit_test_results = {}
 
             for pipeline_i, (path_pipeline, pipeline) in enumerate(
-                    self.pipelines.items()
+                self.pipelines.items()
             ):
                 print(
                     "\n  Unit Testing pipeline %s [%s/%s]"
@@ -275,11 +307,10 @@ class ProphecyBuildTool:
                 )
                 if self.project_language == "python":
                     if os.path.isfile(
-                            os.path.join(path_pipeline_absolute, "test/TestSuite.py")
+                        os.path.join(path_pipeline_absolute, "test/TestSuite.py")
                     ):
                         unit_test_results[path_pipeline] = self.test_python(
-                            path_pipeline_absolute,
-                            path_pipeline
+                            path_pipeline_absolute, path_pipeline
                         )
                 elif self.project_language == "scala":
                     unit_test_results[path_pipeline] = self.test_scala(
@@ -303,18 +334,25 @@ class ProphecyBuildTool:
             sys.exit(1)
 
     def get_python_dependencies(self, path_pipeline_absolute, path_pipeline):
-        if Process.process_sequential(
+        if (
+            Process.process_sequential(
                 [
                     # Export dependencies to egg_info/requires.txt
                     Process(
                         [self.python_cmd, "setup.py", "-q", "egg_info"],
                         path_pipeline_absolute,
-                        is_shell=(self.operating_system == "win32")
+                        is_shell=(self.operating_system == "win32"),
+                        running_message="    Getting Python dependencies...",
                     )
-                ]) == 0:
+                ]
+            )
+            == 0
+        ):
             python_dependencies = []
             egg_info_dir = f"{basename(normpath(path_pipeline))}.egg-info"
-            egg_info_requires = os.path.join(*[path_pipeline_absolute, egg_info_dir, "requires.txt"])
+            egg_info_requires = os.path.join(
+                *[path_pipeline_absolute, egg_info_dir, "requires.txt"]
+            )
             for line in open(egg_info_requires, "r"):
                 if not line.lstrip().startswith("[") and line.strip():
                     python_dependencies.append(line.strip())
@@ -324,10 +362,11 @@ class ProphecyBuildTool:
             sys.exit(1)
 
     def build_python(self, path_pipeline_absolute, path_pipeline):
-        python_dependencies = self.get_python_dependencies(path_pipeline_absolute, path_pipeline)
+        python_dependencies = self.get_python_dependencies(
+            path_pipeline_absolute, path_pipeline
+        )
         return Process.process_sequential(
             [
-
                 # Extract the install_requires and extra_requires and install them
                 Process(
                     [self.pip_cmd, "install", "-q"] + python_dependencies,
@@ -336,13 +375,16 @@ class ProphecyBuildTool:
                 ),
                 # Check for compilation errors
                 Process(
-                    [self.python_cmd, "-m", "compileall", ".", "-q"], path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32")
+                    [self.python_cmd, "-m", "compileall", ".", "-q"],
+                    path_pipeline_absolute,
+                    is_shell=(self.operating_system == "win32"),
                 ),
                 # Generate wheel
                 Process(
-                    [self.python_cmd, "setup.py", "bdist_wheel"], path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32"))
+                    [self.python_cmd, "setup.py", "bdist_wheel"],
+                    path_pipeline_absolute,
+                    is_shell=(self.operating_system == "win32"),
+                ),
             ]
         )
 
@@ -350,9 +392,10 @@ class ProphecyBuildTool:
         return Process.process_sequential(
             [
                 Process(
-                    ["mvn", "clean", "package", "-q", "-DskipTests"],
+                    ["mvn", "clean", "package", "-q", "-DskipTests"]
+                    + self.mvn_params.split(),
                     path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32")
+                    is_shell=(self.operating_system == "win32"),
                 )
             ]
         )
@@ -361,9 +404,10 @@ class ProphecyBuildTool:
         return Process.process_sequential(
             [
                 Process(
-                    ["mvn", "test", "-q", "-Dfabric=" + self.fabric.strip()],
+                    ["mvn", "test", "-q", "-Dfabric=" + self.fabric.strip()]
+                    + self.mvn_params.split(),
                     path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32")
+                    is_shell=(self.operating_system == "win32"),
                 )
             ]
         )
@@ -374,12 +418,16 @@ class ProphecyBuildTool:
                 # Install dependencies of particular pipeline
                 # 1. Export dependencies to egg_info/requires.txt
                 Process(
-                    [self.python_cmd, "setup.py", "-q", "egg_info"], path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32")
+                    [self.python_cmd, "setup.py", "-q", "egg_info"],
+                    path_pipeline_absolute,
+                    is_shell=(self.operating_system == "win32"),
                 ),
                 # 2. Extract the install_requires and extra_requires and install them
                 Process(
-                    [self.pip_cmd, "install", "-q"] + self.get_python_dependencies(path_pipeline_absolute, path_pipeline),
+                    [self.pip_cmd, "install", "-q"]
+                    + self.get_python_dependencies(
+                        path_pipeline_absolute, path_pipeline
+                    ),
                     path_pipeline_absolute,
                     is_shell=(self.operating_system == "win32"),
                 ),
@@ -387,7 +435,7 @@ class ProphecyBuildTool:
                 Process(
                     [self.python_cmd, "-m", "pytest", "-v", "test/TestSuite.py"],
                     path_pipeline_absolute,
-                    is_shell=(self.operating_system == "win32")
+                    is_shell=(self.operating_system == "win32"),
                 ),
             ]
         )
@@ -443,7 +491,7 @@ class ProphecyBuildTool:
             )
 
             if not os.path.isfile(
-                    os.path.join(path_pipeline_absolute, pipeline_dependencies_file)
+                os.path.join(path_pipeline_absolute, pipeline_dependencies_file)
             ):
                 print(
                     f"\n[bold red]Pipeline {path_pipeline} does not exist or is corrupted. [/bold red]"
